@@ -28,7 +28,7 @@
 
 class wxWindow;
 
-class Avi  
+class Avi : public wxThread
 {
 public:
     Avi() {dimFreeMem = 0;}
