@@ -688,19 +688,23 @@ void bayer2rgb24(unsigned char *dst, unsigned char *src, long int width, long in
     
 }
 
-
 void mjpegtoyuv420p(const unsigned char *src, unsigned char *dst,
         int width, int height, unsigned int size) {
     
     uint8_t *yuv[3];
     unsigned char *y, *u, *v;
     int loop;
-    
+    static int interlaced = 0;
+
     yuv[0] = malloc(width * height * sizeof(yuv[0][0]));
     yuv[1] = malloc(width * height / 4 * sizeof(yuv[1][0]));
     yuv[2] = malloc(width * height / 4 * sizeof(yuv[2][0]));
     
-    decode_jpeg_raw((unsigned char*)src, size, 0, 420, width, height, yuv[0], yuv[1], yuv[2]);
+    int ret = decode_jpeg_raw((unsigned char*)src, size, interlaced, 420, width, height, yuv[0], yuv[1], yuv[2]);
+    if(ret) {
+        interlaced = 1;
+        decode_jpeg_raw((unsigned char*)src, size, interlaced, 420, width, height, yuv[0], yuv[1], yuv[2]);
+    }
     
     y=dst;
     u=y+width*height;
