@@ -177,7 +177,7 @@ wxPanel* ConfigureDialog::CreateVideoSettingsPage(wxWindow* parent)
     strAviFormat[0] = _("&none (uncompressed)");
     strAviFormat[1] = _("&xvid");
     
-    aviFormat = new wxRadioBox(panel, ID_AVI_FORMAT, _("&Choose recording compression:"),
+    aviFormat = new wxRadioBox(panel, ID_AVI_FORMAT, _("&Choose compression:"),
         wxDefaultPosition, wxSize(220, 80), 2, strAviFormat);    
     hSizer->Add(aviFormat, 0, wxGROW|wxALL, 10);   
     
@@ -189,7 +189,7 @@ wxPanel* ConfigureDialog::CreateVideoSettingsPage(wxWindow* parent)
         
     vSizer->Add(hSizer, 0, wxALIGN_CENTER_HORIZONTAL|wxEXPAND|wxBOTTOM|wxLEFT|wxRIGHT, 10);
         
-    audio = new wxCheckBox(panel, ID_AUDIO, _("Enable audio recording (xvid only)") );
+    /*audio = new wxCheckBox(panel, ID_AUDIO, _("Enable audio recording (xvid only)") );
     vSizer->Add(audio, wxGROW|wxALL, 15);
     
     wxArrayString validValues = fillValidValues(wxString("dsp*", wxConvUTF8));
@@ -200,7 +200,7 @@ wxPanel* ConfigureDialog::CreateVideoSettingsPage(wxWindow* parent)
     
     vSizer->Add(textAudioDevice, 0, wxALIGN_CENTER|wxALL, 5);
     vSizer->Add(comboAudioDevice, 0, wxALIGN_CENTER|wxBOTTOM, 15);
-    
+    */
     silenceBox = new wxStaticBox(panel, wxID_ANY, _("Add silence for synchronization reason:"), wxDefaultPosition, wxSize(220, 80));
     wxSizer *sSizer = new wxStaticBoxSizer(silenceBox, wxVERTICAL);
     vSizer->Add(sSizer, 0, wxGROW|wxALL, 10);
@@ -210,28 +210,17 @@ wxPanel* ConfigureDialog::CreateVideoSettingsPage(wxWindow* parent)
     textUnit = new wxStaticText(panel, -1, _("(hundredths of a second)"));
     vSizer->Add(textUnit, wxGROW|wxALL, 15);
     
-    boxSizer->Add(vSizer, 0, wxALIGN_CENTER_HORIZONTAL|wxEXPAND|wxBOTTOM|wxLEFT|wxRIGHT, 10);
+    boxSizer->Add(vSizer, 0, wxALIGN_CENTER_HORIZONTAL|wxEXPAND|wxBOTTOM|wxLEFT|wxRIGHT, 10);     
       
-    if(Setting::GetInstance()->GetAudioEnabled())
-        audio->SetValue(true);
-    else {
-        audio->SetValue(false);
-        silenceBox->Enable(false);
-        comboAudioDevice->Enable(false);
-        textAudioDevice->Enable(false);
-        textUnit->Enable(false);
-        hundredthsSlider->Enable(false);
-    }
-    
     if((Setting::GetInstance()->GetCompression() == "none")) {
         aviFormat->SetSelection(0);
         staticCompressionLevelBox->Enable(false);        
         qualitySlider->Enable(false);
-        comboAudioDevice->Enable(false);
-        audio->Enable(false);
+        //comboAudioDevice->Enable(false);
+        //audio->Enable(false);
         silenceBox->Enable(false);
         textUnit->Enable(false);
-        textAudioDevice->Enable(false);
+        //textAudioDevice->Enable(false);
         hundredthsSlider->Enable(false);
     }
     else
@@ -294,18 +283,15 @@ void ConfigureDialog::OnOk(wxCommandEvent& WXUNUSED( event ))
     std::string oldDevice = Setting::GetInstance()->GetDeviceFile();
     std::string oldV4LAPI = Setting::GetInstance()->GetDriverAPI();    
     std::string oldFrameFormat = Setting::GetInstance()->GetFrameFormat();
-    Setting::GetInstance()->SetDeviceFile((const char*)combo->GetValue().mb_str(wxConvUTF8));
-    Setting::GetInstance()->SetAudioDeviceFile((const char*)comboAudioDevice->GetValue().mb_str(wxConvUTF8));
+    Setting::GetInstance()->SetDeviceFile((const char*)combo->GetValue().mb_str(wxConvUTF8));    
     Setting::GetInstance()->SetFrameFormat((const char*)rgbMode->GetStringSelection().mb_str(wxConvUTF8));
     Setting::GetInstance()->SetDriverAPI((const char*)v4lVersion->GetStringSelection().mb_str(wxConvUTF8));
     if(aviFormat->GetStringSelection() == wxString("xvid", wxConvUTF8))
         Setting::GetInstance()->SetCompression((const char*)wxString("xvid", wxConvUTF8).mb_str(wxConvUTF8));
     else
         Setting::GetInstance()->SetCompression((const char*)wxString("none", wxConvUTF8).mb_str(wxConvUTF8));
-    if(audio->IsChecked())
-        Setting::GetInstance()->SetAudioEnabled(true);
-    else
-        Setting::GetInstance()->SetAudioEnabled(false);
+
+    Setting::GetInstance()->SetAudioEnabled(true);
     Setting::GetInstance()->SetCompressionLevel(qualitySlider->GetValue());
     Setting::GetInstance()->SetSilence(hundredthsSlider->GetValue());            
     if((oldV4LAPI != (const char*)v4lVersion->GetStringSelection().mb_str(wxConvUTF8))
@@ -320,23 +306,16 @@ void ConfigureDialog::OnRadioBoxCompression(wxCommandEvent& WXUNUSED(event))
 {
     if(aviFormat->GetSelection()) {
         staticCompressionLevelBox->Enable(true);
-        qualitySlider->Enable(true);
-        audio->Enable(true);
-        if(audio->IsChecked()) {
-            silenceBox->Enable(true);
-            comboAudioDevice->Enable(true);
-            textUnit->Enable(true);
-            textAudioDevice->Enable(true);
-            hundredthsSlider->Enable(true);
-        }
+        qualitySlider->Enable(true);       
+        silenceBox->Enable(true);
+        textUnit->Enable(true);
+        hundredthsSlider->Enable(true);
+        
     }
     else {
         staticCompressionLevelBox->Enable(false);
-        qualitySlider->Enable(false);
-        audio->Enable(false);
-        comboAudioDevice->Enable(false);
-        silenceBox->Enable(false);
-        textAudioDevice->Enable(false);
+        qualitySlider->Enable(false);       
+        silenceBox->Enable(false);        
         textUnit->Enable(false);
         hundredthsSlider->Enable(false);
     }
