@@ -24,7 +24,11 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/mman.h>
+#ifdef HAVE_CAMV4L 
 #include <linux/videodev.h>
+#else
+#include <libv4l1-videodev.h>
+#endif
 #include <sys/ioctl.h>
 #include <sys/types.h>
 #include <sys/stat.h>
