@@ -184,16 +184,14 @@ void Frame::OnPaint( wxPaintEvent& event )
             //if ( !cam.isPWC() )            
             freq = assessFrequency;            
             rec->setParameters( this, filename, freq, width, height );
-            if(compression == "none") {
-                if ( static_cast<AviUncompressed*>(rec)->Create() != wxTHREAD_NO_ERROR ) {
-                    wxLogError( _( "Cannot create video recording thread!" ) );
-                    return;
-                }
 
-                static_cast<AviUncompressed*>(rec)->Run();
+            if ((rec)->Create() != wxTHREAD_NO_ERROR) {
+                wxLogError(_("Cannot create video recording thread!"));
+                return;
             }
+            rec->Run();
 
-            if( rec->setup() ) {
+             if( rec->setup() ) {
                 rstatus = REC_NONE;
                 wxCommandEvent event( wxEVT_COMMAND_MENU_SELECTED, STOP_REC );
                 event.SetInt(1);
@@ -201,6 +199,7 @@ void Frame::OnPaint( wxPaintEvent& event )
             } else {
                 rstatus = REC_CONTINUING;
             }
+            
         }
         else if ( rstatus == REC_CONTINUING ) {
             wxDateTime now = wxDateTime::UNow();
@@ -283,6 +282,8 @@ bool Frame::SetResolution( const std::string &resolution, const std::string &fra
     int freq=0;
     if( cam.isPWC() )
         freq=atoi(frameRate.c_str());
+    else
+        freq = 0;
     if ( !cam.setResolution( w, h, freq ) && deviceOpen ) {
         wxMessageBox( _( "Frame rate/resolution setting not supported.\nPlease try a lower frame rate o resolution." ), _( "Error applying settings" ), wxICON_WARNING );
         return false;
