@@ -35,7 +35,7 @@
 typedef char byte;
 class wxWindow;
 
-class AviUncompressed : public Avi, public wxThread
+class AviUncompressed : public Avi
 {
     public:
         AviUncompressed();
