@@ -49,8 +49,9 @@ VideoForLinux1::~VideoForLinux1()
         munmap( NULL, mmap_size );
 }
 
-bool VideoForLinux1::mMap(int w, int h)
-{    
+bool VideoForLinux1::mMap(int w, int h, int frameRate)
+{
+    frameRate = 0; //ignored
     memset(&v, 0, sizeof(struct video_mmap));
     v.format=frameFormat;
     v.width=w;                     // from 32 to 924 (sometimes limited to 768)
