@@ -30,7 +30,7 @@ public:
     VideoForLinux1();
     ~VideoForLinux1();
     
-    bool mMap(int w, int h);
+    bool mMap(int w, int h, int frameRate=0);
     bool getFrame(char **buffer);  
     bool setResolution(unsigned int width, unsigned int height, unsigned int frameRate=0);
     bool getResolution(unsigned int &width, unsigned int &height, unsigned int &frameRate);
