@@ -41,6 +41,8 @@
 #include <wx/image.h>
 #include <iostream>
 
+#include "pwc-ioctl.h"
+
 VideoForLinux2::VideoForLinux2()
 {
     dev_name = Setting::GetInstance()->GetDeviceFile();
@@ -72,7 +74,7 @@ void VideoForLinux2::closeDevice()
     free(buffers);
 }
 
-bool VideoForLinux2::mMap(int w, int h) {    
+bool VideoForLinux2::mMap(int w, int h, int frameRate) {
     struct v4l2_cropcap cropcap;
     struct v4l2_crop crop;
     struct v4l2_format fmt;
@@ -221,6 +223,29 @@ bool VideoForLinux2::mMap(int w, int h) {
     fmt.fmt.pix.width       = w;
     fmt.fmt.pix.height      = h;
     fmt.fmt.pix.field       = V4L2_FIELD_INTERLACED;
+
+    //setting frame rate
+    if(frameRate) {
+
+        /*
+        //many cams doesn't support these calls
+        v4l2_streamparm parm;
+
+        if (ioctl (fd, VIDIOC_G_PARM, &parm) == -1) {
+            perror("VIDIOC_G_PARM");
+        }
+
+        parm.parm.capture.timeperframe.numerator = 1;
+        parm.parm.capture.timeperframe.denominator = frameRate;
+
+        if (ioctl (fd, VIDIOC_S_PARM, &parm) == -1) {
+            perror("VIDIOC_S_PARM");            
+        }
+         */
+
+        fmt.fmt.pix.priv &= ~PWC_FPS_FRMASK;
+        fmt.fmt.pix.priv |= ( frameRate << PWC_FPS_SHIFT );
+    }
     
     /*enum v4l2_buf_type type;
     type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
@@ -521,8 +546,8 @@ bool VideoForLinux2::setVideoStd(video_std std)
 
 bool VideoForLinux2::setResolution(unsigned int width, unsigned int height, unsigned int frameRate)
 {   
-    frameRate=0; /*avoiding warning*/
-    return mMap(width, height);
+    //frameRate=0; /*avoiding warning*/
+    return mMap(width, height, frameRate);
 }
 
 bool VideoForLinux2::getResolution(unsigned int &width, unsigned int &height, unsigned int &frameRate)
@@ -537,6 +562,7 @@ bool VideoForLinux2::getResolution(unsigned int &width, unsigned int &height, un
     }
     width = fmt.fmt.pix.width;
     height = fmt.fmt.pix.height;
+    frameRate = ( fmt.fmt.pix.priv & PWC_FPS_FRMASK ) >> PWC_FPS_SHIFT;
     printf("width: %d, height %d\n", width, height);
     return true;
 }
