@@ -46,7 +46,7 @@ public:
     ~VideoForLinux2();
     
     void closeDevice();
-    bool mMap(int w, int h);
+    bool mMap(int w, int h, int frameRate=0);
     bool getFrame(char **buffer);
     bool setResolution(unsigned int width, unsigned int height, unsigned int frameRate=0);
     bool getResolution(unsigned int &width, unsigned int &height, unsigned int &frameRate);
@@ -59,8 +59,10 @@ public:
     bool setSaturation(unsigned int value);
     bool getSaturation(unsigned int &value); 
     bool setVideoStd(video_std std);
+
+    int getPixelFormat() {return pixelFormat;}
         
-private:
+private:    
     bool init_mmap();
     void setControls();
     void enumerateMenu(struct v4l2_queryctrl &queryctrl, struct v4l2_querymenu querymenu);
