@@ -32,6 +32,7 @@
 #include <wx/aboutdlg.h>
 #include <wx/thread.h>
 
+#include <linux/videodev2.h>
 #include "device.h"
 #include <iostream>
 #include <sstream>
@@ -130,10 +131,18 @@ wxCam::wxCam( const wxString& title )
         Setting::GetInstance()->SetAlreadyOpen();
         struct video_capability caps;
         struct video_picture pic;
-        cam.queryCapabilities( &caps );
-        wxString msg = _( "Device found in your system: " ) +  wxString( "\n", wxConvUTF8 );
-        msg += wxString(caps.name, wxConvUTF8);
+        wxString msg;
+        if(cam.queryCapabilities( &caps )) {
+            msg = _( "Device found in your system: " ) +  wxString( "\n", wxConvUTF8 );
+            msg += wxString(caps.name, wxConvUTF8);
+        } else {
+            struct v4l2_capability v2caps;
+            cam.queryCapabilities(&v2caps);
+            msg = _( "Device found in your system: " ) +  wxString( "\n", wxConvUTF8 );
+            msg += wxString((char*)v2caps.card, wxConvUTF8);
+        }
         wxMessageBox( msg,  _( "Hardware found" ), wxICON_INFORMATION );
+
         /*cam.getPictureFunctions( &pic );
         if ( pic.palette == VIDEO_PALETTE_YUV420P || frame->isPWC() ) {
             Setting::GetInstance()->SetFrameFormat( "YUV420P" );
@@ -297,11 +306,12 @@ void wxCam::OnAbout( wxCommandEvent& WXUNUSED( event ) )
     wxAboutDialogInfo info;
     
     info.SetName( _T( "wxCam" ) );
-    info.SetVersion( wxString("1.0.8", wxConvUTF8) );
+    info.SetVersion( wxString("1.1", wxConvUTF8) );
     info.SetDescription( _( "A webcam application for linux" ) );
     info.SetCopyright( _T( "(C) 2011 Marco Lorrai" ) );
     info.AddDeveloper( _T( "Marco Lorrai" ) );
     info.AddDeveloper( _T( "Örjan Medhage" ) );
+    info.SetWebSite(wxT("wxcam.sourceforge.net"));
     // we can add a second developer
     //info.AddDeveloper(_T("A.N. Other"));
     
@@ -335,34 +345,53 @@ void wxCam::OnShowCapabilities( wxCommandEvent& WXUNUSED( event ) )
 {
     struct video_capability caps;
     if ( !cam.queryCapabilities( &caps ) ) {
-        wxMessageBox( _( "Error querying webcam capabilities.\nPerhaps the device hasn't been correctly opened." ), _( "Capabilities" ), wxICON_WARNING );
-        return;
+        //Trying v4l2 query...
+        struct v4l2_capability v2caps;
+        if ( !cam.queryCapabilities( &v2caps ) ) {
+            wxMessageBox( _( "Error querying webcam capabilities.\nPerhaps the device hasn't been correctly opened." ), _( "Capabilities" ), wxICON_WARNING );
+            return;
+        }
+        std::stringstream ss;
+        std::string str;
+        ss << (const char*) wxString(_("Driver: ")).mb_str(wxConvUTF8) << v2caps.driver << "\n";
+
+        ss << (const char*) wxString(_("Card: ")).mb_str(wxConvUTF8) << v2caps.card << "\n";
+        str = ss.str();
+
+        ss.str("");
+        if (v2caps.capabilities & V4L2_CAP_AUDIO)
+            ss << (const char*) wxString(_("Audio: ")).mb_str(wxConvUTF8) << (const char*) wxString(_("Yes")).mb_str(wxConvUTF8) << "\n";
+        else
+            ss << (const char*) wxString(_("Audio: ")).mb_str(wxConvUTF8) << (const char*) wxString(_("No")).mb_str(wxConvUTF8) << "\n";
+        str += ss.str();        
+
+        wxMessageBox(wxString(str.c_str(), wxConvUTF8), _("Webcam Capabilities     "), wxICON_INFORMATION);
+    } else {
+        std::stringstream ss;
+        std::string str;
+
+        ss << (const char*) wxString(_("Name: ")).mb_str(wxConvUTF8) << caps.name << "\n";
+
+        ss << (const char*) wxString(_("Channels: ")).mb_str(wxConvUTF8) << caps.channels << "\n";
+        str = ss.str();
+
+        ss.str("");
+        if (caps.audios)
+            ss << (const char*) wxString(_("Audio: ")).mb_str(wxConvUTF8) << (const char*) wxString(_("Yes")).mb_str(wxConvUTF8) << "\n";
+        else
+            ss << (const char*) wxString(_("Audio: ")).mb_str(wxConvUTF8) << (const char*) wxString(_("No")).mb_str(wxConvUTF8) << "\n";
+        str += ss.str();
+
+        ss.str("");
+        ss << (const char*) wxString(_("Min resolution: ")).mb_str(wxConvUTF8) << caps.minwidth << "x" << caps.minheight << "\n";
+        str += ss.str();
+
+        ss.str("");
+        ss << (const char*) wxString(_("Max resolution: ")).mb_str(wxConvUTF8) << caps.maxwidth << "x" << caps.maxheight << "\n";
+        str += ss.str();
+
+        wxMessageBox(wxString(str.c_str(), wxConvUTF8), _("Webcam Capabilities     "), wxICON_INFORMATION);
     }
-    
-    std::stringstream ss;
-    std::string str;
-    
-    ss<<(const char*)wxString( _( "Name: " ) ).mb_str(wxConvUTF8) <<caps.name<<"\n";
-    
-    ss<<(const char*)wxString( _( "Channels: " ) ).mb_str(wxConvUTF8) <<caps.channels<<"\n";
-    str = ss.str();
-    
-    ss.str( "" );
-    if ( caps.audios )
-        ss<<(const char*)wxString( _( "Audio: " ) ).mb_str(wxConvUTF8) <<(const char*)wxString( _( "Yes" ) ).mb_str(wxConvUTF8) <<"\n";
-    else
-        ss<<(const char*)wxString( _( "Audio: " ) ).mb_str(wxConvUTF8) <<(const char*)wxString( _( "No" ) ).mb_str(wxConvUTF8) <<"\n";
-    str += ss.str();
-    
-    ss.str( "" );
-    ss<<(const char*)wxString( _( "Min resolution: " ) ).mb_str(wxConvUTF8) <<caps.minwidth<<"x"<<caps.minheight<<"\n";
-    str += ss.str();
-    
-    ss.str( "" );
-    ss<<(const char*)wxString( _( "Max resolution: " ) ).mb_str(wxConvUTF8) <<caps.maxwidth<<"x"<<caps.maxheight<<"\n";
-    str += ss.str();
-    
-    wxMessageBox( wxString(str.c_str(), wxConvUTF8), _( "Webcam Capabilities     " ), wxICON_INFORMATION );
 }
 
 void wxCam::OnPictureFunctions( wxCommandEvent& WXUNUSED( event ) ) 
@@ -396,6 +425,8 @@ void wxCam::OnSettingResolution( wxCommandEvent& WXUNUSED( event ) )
                 return;
             
             wxString valueFrameRate = resDlg->GetFrameRate();
+            if(!valueFrameRate.size())
+                valueFrameRate = wxT("10");
             /*if ( valueFrameRate == wxString("- - -", wxConvUTF8) || valueFrameRate.empty() )
                 return;*/
 
